%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Technical Note TN125
% Parameters for 'LLC converter with passive load'
% Copyright imperix ltd, 2024
% dev@imperix.ch
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% =================== System parameters ======================== %%

ControlFreq    = 20e3;              % control interrupt frequency [Hz]
ControlPeriod  = 1/ControlFreq;     % control interrupt period [s]

% Deadtime
dt = 100e-9;                        % module deadtime [s]

% Transformer magnetization
charge_time = 3;                    % transformer precharge time [s]

% Frequency limits (to remain in ZVS)
freq_lim = [55 200]*1e3;            % upper and lower frequency limits [Hz]

%% =================== Plant model ======================== %%

% Resonant tank parameters
Lr = 20.84e-6;                      % resonant inductance [H]
Cr = 109.5e-9;                      % resonant capacitance [F]
Lm = 89.76e-6;                      % magnetizing inductance [H]
n  = 8/9;                           % turns ratio (Np/Ns) [-]

Llk_s = 2e-6;                       % secondary leakage inductance [H]


% Module capacitance
C_8024 = 256e-6;                    % PEB 8024 module capacitance [F]
C_4050 = 1.1e-3;                    % PEB 4050 module capacitance [F]

% Load
Rload = 99;                         % load resistance [Ohm]

% Initialization
Vin         = 90;                   % input voltage [V]
Vout_init   = 236;                  % initial output voltage (in sim) [V]
